==> jktool-0.0.8.tar.gz: jktool/phpplus.sh <==
#! /bin/sh

# @ (#) install.sh
# Copyright 2000-2003 by Jaeku Kim..
#                                       KOREA (Republic of) 
# @ author Jaeku - Kim  Email Address : pools2@users.kldp.net
# 2002/08/14 
# Version 1.00.00
# - Apache Easy Support Tool

stop=0
#ġ  
install_path="/home/jktool/"
#ġ  
apache_path="apache_1.3.29"
while test $stop -eq 0
do
cat << ENDOFMENU
=========================================
 Apache Easy install Program 0.0.1 
-----------------------------------------
 0. Introduce (Ұ)
 1. View of License (̼ )
 2. Install (ġ)
 3. Uninstall ()
 4. Exit
=========================================
  Select Number? (0~4) :
ENDOFMENU
   read num
   echo
   case $num in
      "0") 'clear'
           'cat' introduce.txt|more
              ;;
      "1") 'clear'
           'cat' license.txt|more
              ;;
     "2")
#	MySql  install
	 useradd jktool 
	prepath=`pwd`
	./mysqli.sh
#	zlib
	cd $prepath
	cd zlib-1.1.3
	./configure
	make
	make install
	cp -f *.h /usr/local/include/
#	FreeType-2.0.2 install
	cd $prepath
        cd freetype-2.0.9
	./configure 
	make
	make install
#	lib-png
	cd $prepath
	cd libpng-1.0.12
	make -f scripts/makefile.linux
	cp -f *.h /usr/local/include/
	cp -f lib* /usr/local/lib/
#	jpeg6b install
	cd $prepath
	cd jpeg-6b
	./configure 
	make
	make install
	cp -f libjpeg*.a /usr/lib/
	cp -f *.h /usr/local/include/
#       gd 2.0.20 install
	cd $prepath
	cd gd-2.0.20
	./configure 
	make
	make install
	cp -f libgd* /usr/lib/
	cp -f *.h /usr/local/include/
#	Apache install
	  cd $prepath
          cd $apache_path
          echo "Web User add -    "
          echo "Install Config - ν ȯ漳"
	  ./configure --prefix=$install_path'/apache'
	  cd $prepath 
	  cd  php-4.3.6
#	  ./configure --with-apache=$prepath/$apache_path \--with-mysql=$install_path/mysql \--with-jpeg-dir=/home/jktool \--with-gd=/home/jktool\--enable-track-vars \--enable-ftp \--enable-calendar \--with-ttf=/home/jktool
	  ./configure --with-apache=$prepath/$apache_path \--with-jpeg-dir=/usr/local \--enable-track-vars \--enable-ftp \--enable-calendar \--with-ttf=/usr/local \--with-png-dir=/usr/local \--with-gd \--with-zlib=/usr/local
	  make
	  make install
          cp php.ini-dist /usr/local/lib/php.ini 
	  cd $prepath  
 	  cd $apache_path 
	 ./configure --prefix=$install_path'apache' \--activate-module=src/modules/php4/libphp4.a   
          echo "Install - ν"
	  make 
	  make install
          echo "Web Forder Setup -   մϴ"
          mkdir $install_path'web'
	  mkdir $install_path'web/cgi-bin'
	  mkdir $install_path'web/html'
	  chown jktool.jktool -R $install_path/web
          cd ..
          cp -f conf/httpd_php.conf $install_path'apache/conf/httpd.conf'
          echo "Sucessfull - ϷǾϴ."
	  stop=1;
          ;;
      "3")
         uninstall
	stop=1;
          ;;
      "4")
          stop=1;
          ;;
    esac
done

==> jktool-0.0.10.tar.gz: jktool/phpplus.sh <==
#! /bin/sh

# @ (#) install.sh
# Copyright 2000-2004 by Jaeku Kim..
#                                       KOREA (Republic of) 
# @ author Jaeku - Kim  Email Address : pools2@users.kldp.net
# 2002/08/14 
# Version 1.00.00
# - Apache Easy Support Tool

stop=0
#ġ  
install_path="/home/jktool/"
#ġ  
apache_path="apache_1.3.31"
while test $stop -eq 0
do
cat << ENDOFMENU
=========================================
 Apache Easy install Program 0.0.1 
-----------------------------------------
 0. Introduce (Ұ)
 1. View of License (̼ )
 2. Install (ġ)
 3. Uninstall ()
 4. Exit
=========================================
  Select Number? (0~4) :
ENDOFMENU
   read num
   echo
   case $num in
      "0") 'clear'
           'cat' introduce.txt|more
              ;;
      "1") 'clear'
           'cat' license.txt|more
              ;;
     "2")
#	MySql  install
	 useradd jktool 
	prepath=`pwd`
	./mysqli.sh
#	zlib
	cd $prepath
	cd zlib-1.1.3
	./configure
	make
	make install
	cp -f *.h /usr/local/include/
#	FreeType-2.0.2 install
	cd $prepath
        cd freetype-2.0.9
	./configure 
	make
	make install
#	lib-png
	cd $prepath
	cd libpng-1.0.12
	make -f scripts/makefile.linux
	cp -f *.h /usr/local/include/
	cp -f lib* /usr/local/lib/
#	jpeg6b install
	cd $prepath
	cd jpeg-6b
	./configure 
	make
	make install
	cp -f libjpeg*.a /usr/lib/
	cp -f *.h /usr/local/include/
#       gd 2.0.23 install
	cd $prepath
	cd gd-2.0.23
	./configure 
	make
	make install
	cp -f libgd* /usr/lib/
	cp -f *.h /usr/local/include/
#	Apache install
	  cd $prepath
          cd $apache_path
          echo "Web User add -    "
          echo "Install Config - ν ȯ漳"
	  ./configure --prefix=$install_path'/apache'
	  cd $prepath 
	  cd  php-4.3.8
	  ./configure --with-apache=$prepath/$apache_path \--with-jpeg-dir=/usr/local \--enable-track-vars \--enable-ftp \--enable-calendar \--with-ttf=/usr/local \--with-png-dir=/usr/local \--with-gd \--with-zlib=/usr/local \--enable-exif \--enable-mbstring \--enable-gd-native-ttf \--enable-gd-jis-conv \--with-freetype-dir=/usr/local \--enable-experimental-zts \--enable-zend-multibyte
	  make
	  make install
          cp php.ini-dist /usr/local/lib/php.ini 
	  cd $prepath  
 	  cd $apache_path 
	 ./configure --prefix=$install_path'apache' \--activate-module=src/modules/php4/libphp4.a   
          echo "Install - ν"
	  make 
	  make install
          echo "Web Forder Setup -   մϴ"
          mkdir $install_path'web'
	  mkdir $install_path'web/cgi-bin'
	  mkdir $install_path'web/html'
	  chown jktool.jktool -R $install_path/web
          cd ..
          cp -f conf/httpd_php.conf $install_path'apache/conf/httpd.conf'
          echo "Sucessfull - ϷǾϴ."
	  stop=1;
          ;;
      "3")
         uninstall
	stop=1;
          ;;
      "4")
          stop=1;
          ;;
    esac
done
